summaryrefslogtreecommitdiffstats
path: root/src/kicondialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/kicondialog.h')
-rw-r--r--src/kicondialog.h88
1 files changed, 44 insertions, 44 deletions
diff --git a/src/kicondialog.h b/src/kicondialog.h
index 01291ae..6432764 100644
--- a/src/kicondialog.h
+++ b/src/kicondialog.h
@@ -13,8 +13,8 @@
* exact licensing terms.
*/
-#ifndef __KIconDialog_h__
-#define __KIconDialog_h__
+#ifndef __TDEIconDialog_h__
+#define __TDEIconDialog_h__
#include <tqstring.h>
#include <tqstringlist.h>
@@ -24,16 +24,16 @@
#include <kdialogbase.h>
#include <kiconview.h>
-#include <kiconcanvas.h> // FIXME: BCI KDE 3 expects KIconCanvas to be defined in kicondialog.h
+#include <kiconcanvas.h> // FIXME: BCI KDE 3 expects TDEIconCanvas to be defined in kicondialog.h
-class KIconDialogUI;
+class TDEIconDialogUI;
class TQComboBox;
class TQTimer;
class TQKeyEvent;
class TQRadioButton;
class KProgress;
-class KIconLoader;
+class TDEIconLoader;
/**
* Dialog for interactive selection of icons. Use the function
@@ -41,7 +41,7 @@ class KIconLoader;
*
* @short An icon selection dialog.
*/
-class TDEIO_EXPORT KIconDialog: public KDialogBase
+class TDEIO_EXPORT TDEIconDialog: public KDialogBase
{
Q_OBJECT
@@ -50,16 +50,16 @@ public:
/**
* Constructs an icon selection dialog using the global iconloader.
*/
- KIconDialog(TQWidget *parent=0L, const char *name=0L);
+ TDEIconDialog(TQWidget *parent=0L, const char *name=0L);
/**
* Constructs an icon selection dialog using a specific iconloader.
*/
- KIconDialog(KIconLoader *loader, TQWidget *parent=0,
+ TDEIconDialog(TDEIconLoader *loader, TQWidget *parent=0,
const char *name=0);
/**
* Destructs the dialog.
*/
- ~KIconDialog();
+ ~TDEIconDialog();
/**
* Sets a strict icon size policy for allowed icons. When true,
@@ -86,7 +86,7 @@ public:
/**
* Sets the size of the icons to be shown / selected.
- * @see KIcon::StdSizes
+ * @see TDEIcon::StdSizes
* @see iconSize
*/
void setIconSize(int size);
@@ -101,8 +101,8 @@ public:
/**
* @deprecated in KDE 3.0, use the static method getIcon instead.
*/
- TQString selectIcon(KIcon::Group group=KIcon::Desktop, KIcon::Context
- context=KIcon::Application, bool user=false);
+ TQString selectIcon(TDEIcon::Group group=TDEIcon::Desktop, TDEIcon::Context
+ context=TDEIcon::Application, bool user=false);
#endif
/**
@@ -110,8 +110,8 @@ public:
* getIcon().
*
*/
- void setup( KIcon::Group group,
- KIcon::Context context = KIcon::Application,
+ void setup( TDEIcon::Group group,
+ TDEIcon::Context context = TDEIcon::Application,
bool strictIconSize = false, int iconSize = 0,
bool user = false );
/* FIXME: KDE4 remove -- same as next method with default arguments */
@@ -124,7 +124,7 @@ public:
*
* @since 3.3
*/
- void setup( KIcon::Group group, KIcon::Context context,
+ void setup( TDEIcon::Group group, TDEIcon::Context context,
bool strictIconSize, int iconSize, bool user, bool lockContext,
bool lockBrowse );
// FIXME: KDE4 add default arguments (right now this would cause ambiguity with previous method)
@@ -132,7 +132,7 @@ public:
/**
* exec()utes this modal dialog and returns the name of the selected icon,
* or TQString() if the dialog was aborted.
* @returns the name of the icon, suitable for loading with KIconLoader.
* @see getIcon
*/
TQString openDialog();
@@ -159,11 +159,11 @@ public:
* @param user Begin with the "user icons" instead of "system icons".
* @param parent The parent widget of the dialog.
* @param caption The caption to use for the dialog.
* @return The name of the icon, suitable for loading with KIconLoader.
* @version New in 3.0
*/
- static TQString getIcon(KIcon::Group group=KIcon::Desktop,
- KIcon::Context context=KIcon::Application,
+ static TQString getIcon(TDEIcon::Group group=TDEIcon::Desktop,
+ TDEIcon::Context context=TDEIcon::Application,
bool strictIconSize=false, int iconSize = 0,
bool user=false, TQWidget *parent=0,
const TQString &caption=TQString());
@@ -186,7 +186,7 @@ private:
void showIcons();
int mGroupOrSize;
- KIcon::Context mContext;
+ TDEIcon::Context mContext;
int mType;
TQStringList mFileList;
@@ -197,26 +197,26 @@ private:
TQRadioButton *mpRb1, *mpRb2;
KProgress *mpProgress;
- KIconLoader *mpLoader;
+ TDEIconLoader *mpLoader;
- KIconCanvas *mpCanvas; // FIXME: obsolete, remove in KDE4
+ TDEIconCanvas *mpCanvas; // FIXME: obsolete, remove in KDE4
protected:
virtual void virtual_hook( int id, void* data );
private:
- class KIconDialogPrivate;
- KIconDialogPrivate *d;
+ class TDEIconDialogPrivate;
+ TDEIconDialogPrivate *d;
};
/**
* A pushbutton for choosing an icon. Pressing on the button will open a
* KIconDialog for the user to select an icon. The current icon will be
* displayed on the button.
*
- * @see KIconDialog
+ * @see TDEIconDialog
* @short A push button that allows selection of an icon.
*/
-class TDEIO_EXPORT KIconButton: public TQPushButton
+class TDEIO_EXPORT TDEIconButton: public TQPushButton
{
Q_OBJECT
@@ -227,18 +227,18 @@ class TDEIO_EXPORT KIconButton: public TQPushButton
public:
/**
* Constructs a KIconButton using the global iconloader.
*/
- KIconButton(TQWidget *parent=0L, const char *name=0L);
+ TDEIconButton(TQWidget *parent=0L, const char *name=0L);
/**
* Constructs a KIconButton using a specific KIconLoader.
*/
- KIconButton(KIconLoader *loader, TQWidget *parent, const char *name=0L);
+ TDEIconButton(TDEIconLoader *loader, TQWidget *parent, const char *name=0L);
/**
* Destructs the button.
*/
- ~KIconButton();
+ ~TDEIconButton();
/**
* Sets a strict icon size policy for allowed icons. When true,
@@ -252,16 +252,16 @@ public:
bool strictIconSize() const;
/**
* Sets the icon group and context. Use KIcon::NoGroup if you want to
* allow icons for any group in the given context.
*/
- void setIconType(KIcon::Group group, KIcon::Context context, bool user=false);
+ void setIconType(TDEIcon::Group group, TDEIcon::Context context, bool user=false);
/**
* Same as above method, but allows you to specify whether user and custom mode should be locked.
*/
- void setIconType(KIcon::Group group, KIcon::Context context, bool user, bool lockContext, bool lockBrowse);
+ void setIconType(TDEIcon::Group group, TDEIcon::Context context, bool user, bool lockContext, bool lockBrowse);
/* FIXME: KDE4 this should replace the above method using default params */
/**
@@ -291,7 +291,7 @@ public:
/**
* Sets the size of the icon to be shown / selected.
- * @see KIcon::StdSizes
+ * @see TDEIcon::StdSizes
* @see iconSize
*/
void setIconSize( int size );
@@ -314,18 +314,18 @@ private slots:
void newIconName(const TQString& name);
private:
- void init( KIconLoader *loader );
+ void init( TDEIconLoader *loader );
bool mbUser;
- KIcon::Group mGroup;
- KIcon::Context mContext;
+ TDEIcon::Group mGroup;
+ TDEIcon::Context mContext;
TQString mIcon;
- KIconDialog *mpDialog;
- KIconLoader *mpLoader;
- class KIconButtonPrivate;
- KIconButtonPrivate *d;
+ TDEIconDialog *mpDialog;
+ TDEIconLoader *mpLoader;
+ class TDEIconButtonPrivate;
+ TDEIconButtonPrivate *d;
};
-#endif // __KIconDialog_h__
+#endif // __TDEIconDialog_h__
@@ -132,7 +132,7 @@ public:
* exec()utes this modal dialog and returns the name of the selected icon,
* or TQString() if the dialog was aborted.
- * @returns the name of the icon, suitable for loading with KIconLoader.
+ * @returns the name of the icon, suitable for loading with TDEIconLoader.
* @see getIcon
*/
@@ -159,11 +159,11 @@ public:
* @param parent The parent widget of the dialog.
* @param caption The caption to use for the dialog.
- * @return The name of the icon, suitable for loading with KIconLoader.
+ * @return The name of the icon, suitable for loading with TDEIconLoader.
* @version New in 3.0
*/
@@ -197,26 +197,26 @@ private:
/**
* A pushbutton for choosing an icon. Pressing on the button will open a
- * KIconDialog for the user to select an icon. The current icon will be
+ * TDEIconDialog for the user to select an icon. The current icon will be
* displayed on the button.
*
@@ -227,18 +227,18 @@ class TDEIO_EXPORT KIconButton: public TQPushButton
public:
/**
- * Constructs a KIconButton using the global iconloader.
+ * Constructs a TDEIconButton using the global iconloader.
*/
@@ -227,18 +227,18 @@ class TDEIO_EXPORT KIconButton: public TQPushButton
/**
- * Constructs a KIconButton using a specific KIconLoader.
+ * Constructs a TDEIconButton using a specific TDEIconLoader.
*/
@@ -252,16 +252,16 @@ public:
bool strictIconSize() const;
/**
- * Sets the icon group and context. Use KIcon::NoGroup if you want to
+ * Sets the icon group and context. Use TDEIcon::NoGroup if you want to
* allow icons for any group in the given context.
*/